==> mythplugins-0.18.1.tar.bz2: mythplugins-0.18.1/mythdvd/i18n/mythdvd_es.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>La conexión al proceso de trascodificación se interrumpió. Eso no es bueno.</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>No puede conectarse al Myth Transcoding Daemon (MTD). Puede intentar pulsar cualquier tecla numérica para iniciarlo. Si vuelve a ver este mensaje, algo va mal.</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>Intentando inicial su mtd no reconoció el nombre de la máquina. Esto es un error fatal.</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>Error de comunicaciones. Es un error irrecuperable.</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>Algo va mal, pero no puedo determinarse la causa.</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>Tarea %1 de %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>No hay tareas ni nada más que hacer. Puede pulsar 0 para ripear un DVD.</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>Sin tareas. Comprobando/Esperando un nuevo DVD.</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>Sin tareas ni nada más que hacer. Puede pulsar 0 si desea ripear un nuevo DVD.</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>Cancelando...</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>0 Nuevo Rip</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>9 Cancelar Tarea</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>

No se dispone de comando definido para reproducir VCD.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>Bien, iré a la configuración</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>

No tiene definido dispositivo de VCD.</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation>

No se dispone de comando definido para reproducir DVD.</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>

No tiene definido dispositivo de para deproducir DVD.</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>Localización del dispositivo de VCD</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>Este dispositivo debe de existir y el usuario de MythDVD requiere permiso de lectura sobre él.</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>Localización del dispositivo de DVD</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Configuración General</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>Comando para reproducir DVD</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>Puede especificarse cualquier comando para reproducir DVD (por ej: mplayer, ogle, xine...). Si se especifica %s se sustituirá por el dispositivo de DVD (por ej: /dev/dvd).</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>Comando para reproducir VCD</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>Puede especificarse cualquier comando para reproducir VCD (por ej: mplayer, xine...). Si se especifica %s se sustituirá por el dispositivo de VCD (por ej: /dev/cdrom).</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>Configuración de DVD</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>Configuración de VCD</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>Directorio para archivos temporales</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>Este directorio debe de existir y el usuario que ejecuta MythDVD requiere  permiso de escritura sobre el mismo.</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>Comando para reproducir títulos</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>Este comando se ejecutará para previsualizar un título de un DVD. Si se encuentra %t se sustituirá con el título, %d para el dispositivo, %a para la pista de audio, %c para el canal de audio.</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>Parámetros de subtítulos:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>Si selecciona ripear con subtítulos, estos parámetros se añadirán al final del comando de reproducción para permitir previsualizar los subtítulos. Si se especifica %s se sustituirá con la pista de subtítulos.</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>Comando de trascodificación básico</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>Comando básico (sin argumentos) para ejecutar la trascodificación en su sistema.</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>Número de puerto para el MTD</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>El número de puerto a emplear para la comunicación con el MTD (Myth Transcoding Daemon)</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>Trazas del MTC a la ventana de terminal</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>Si se activa, el MTD (Myth Transcoding Daemon) dará salida a la ventana desde donde se lanzó. En caso contrario, las trazas estarán en el archivo mtd.log que se encontrará en el nivel superior del directorio donde se vuelcan los ripeados.</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>Trascodificar audio AC3</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>Si se activa, el MTD (Myth Transcoding Daemon) conservará, por defecto, el AC3 (Dolby Digital) en la trascodificación.</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>Usar xvid en lugar de divx</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>Si se activa, MythDVD usará xvid (abierto, libre) en lugar de divx si es que ello es posible.</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>Prioridad (nice) del MTD</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Determina la prioridad del MTD (Myth Transcoding Daemon). Un valor más alto significa una prioridad inferior (más procesador para el resto de tareas).</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation>Fragmentación de los archivos de vídeo</translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation>Si se especifica un valor distinto de 0, los arxivos ripeados se fragmentarán en ficheros de este tamaño (en MB). Aplica tanto a los archivos temporales como a los definitivos.</translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>Configuración del ripeador de DVD</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>Configuración del MTD</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>Esperando acceder al DVD</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>Ripeando hacia el archivo ~ </translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>Ripeado perfecto de %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>Trascodificación de %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>Esperando autorización para iniciar la trascodificación</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>Trascodificando, paso 1 de 2 ~ </translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>Trascodificando, paso 2 de 2 ~ </translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>Trascodificando ~ </translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation>El trascodificador está pensando</translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>Tareas de trascodificación simultáneas</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>Determina el número de tareas simultáneas de trascodificación. Si se define 1 (por defecto) habrá sólo una.</translation>
    </message>
    <message>
        <source>On DVD insertion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media Monitoring should be turned on to allow this feature (Setup -&gt; General -&gt; CD/DVD Monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display mythdvd menu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>Ripear/Trascodificar</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>Trabajo 1 de 1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Duración:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>Seleccione:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Calidad:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>Banda de audio:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>Audio AC3:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>Subtítulos:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>Ver:</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>Título 1 de 1</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - Título de %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfecto</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>Título %1 de %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0 Procesar el título seleccionado</translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0 Procesar los títulos seleccionados</translation>
    </message>
</context>
</TS>

==> mythplugins-0.19.tar.bz2: mythplugins-0.19/mythdvd/i18n/mythdvd_es.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>La conexión al proceso de trascodificación se interrumpió. Eso no es bueno.</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>No puede conectarse al Myth Transcoding Daemon (MTD). Puede intentar pulsar cualquier tecla numérica para iniciarlo. Si vuelve a ver este mensaje, algo va mal.</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>Intentando inicial su mtd no reconoció el nombre de la máquina. Esto es un error fatal.</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>Error de comunicaciones. Es un error irrecuperable.</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>Algo va mal, pero no puedo determinarse la causa.</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>Tarea %1 de %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>No hay tareas ni nada más que hacer. Puede pulsar 0 para ripear un DVD.</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>Sin tareas. Comprobando/Esperando un nuevo DVD.</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>Sin tareas ni nada más que hacer. Puede pulsar 0 si desea ripear un nuevo DVD.</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>Cancelando...</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>0 Nuevo Rip</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>9 Cancelar Tarea</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>

No se dispone de comando definido para reproducir VCD.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>Bien, iré a la configuración</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>

No tiene definido dispositivo de VCD.</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation type="obsolete">

No se dispone de comando definido para reproducir DVD.</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>

No tiene definido dispositivo de para deproducir DVD.</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>Localización del dispositivo de VCD</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>Este dispositivo debe de existir y el usuario de MythDVD requiere permiso de lectura sobre él.</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>Localización del dispositivo de DVD</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Configuración General</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>Comando para reproducir DVD</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>Puede especificarse cualquier comando para reproducir DVD (por ej: mplayer, ogle, xine...). Si se especifica %s se sustituirá por el dispositivo de DVD (por ej: /dev/dvd).</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>Comando para reproducir VCD</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>Puede especificarse cualquier comando para reproducir VCD (por ej: mplayer, xine...). Si se especifica %s se sustituirá por el dispositivo de VCD (por ej: /dev/cdrom).</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>Configuración de DVD</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>Configuración de VCD</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>Directorio para archivos temporales</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>Este directorio debe de existir y el usuario que ejecuta MythDVD requiere  permiso de escritura sobre el mismo.</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>Comando para reproducir títulos</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>Este comando se ejecutará para previsualizar un título de un DVD. Si se encuentra %t se sustituirá con el título, %d para el dispositivo, %a para la pista de audio, %c para el canal de audio.</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>Parámetros de subtítulos:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>Si selecciona ripear con subtítulos, estos parámetros se añadirán al final del comando de reproducción para permitir previsualizar los subtítulos. Si se especifica %s se sustituirá con la pista de subtítulos.</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>Comando de trascodificación básico</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>Comando básico (sin argumentos) para ejecutar la trascodificación en su sistema.</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>Número de puerto para el MTD</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>El número de puerto a emplear para la comunicación con el MTD (Myth Transcoding Daemon)</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>Trazas del MTC a la ventana de terminal</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>Si se activa, el MTD (Myth Transcoding Daemon) dará salida a la ventana desde donde se lanzó. En caso contrario, las trazas estarán en el archivo mtd.log que se encontrará en el nivel superior del directorio donde se vuelcan los ripeados.</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>Recodificar audio AC3</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>Si se activa, el MTD (Myth Transcoding Daemon) conservará, por defecto, el AC3 (Dolby Digital) en la trascodificación.</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>Usar xvid en lugar de divx</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>Si se activa, MythDVD usará xvid (abierto, libre) en lugar de divx si es que ello es posible.</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>Prioridad (nice) del MTD</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Determina la prioridad del MTD (Myth Transcoding Daemon). Un valor más alto significa una prioridad inferior (más procesador para el resto de tareas).</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation>Fragmentación de los archivos de vídeo</translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation>Si se especifica un valor distinto de 0, los arxivos ripeados se fragmentarán en ficheros de este tamaño (en MB). Aplica tanto a los archivos temporales como a los definitivos.</translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>Configuración del ripeador de DVD</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>Configuración del MTD</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>Esperando acceder al DVD</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>Ripeando hacia el archivo ~ </translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>Ripeado perfecto de %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>Recodificación de %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>Esperando autorización para iniciar la recodificación</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>Recodificando, paso 1 de 2 ~ </translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>Recodificando, paso 2 de 2 ~ </translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>Recodificando ~ </translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation>El recodificador está pensando</translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>Tareas de recodificación simultáneas</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>Determina el número de tareas simultáneas de recodificación. Si se define 1 (por defecto) habrá sólo una.</translation>
    </message>
    <message>
        <source>On DVD insertion</source>
        <translation>Al insertar DVD</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>No hacer nada</translation>
    </message>
    <message>
        <source>Play DVD</source>
        <translation>Reproducir DVD</translation>
    </message>
    <message>
        <source>Rip DVD</source>
        <translation>Ripear DVD</translation>
    </message>
    <message>
        <source>Media Monitoring should be turned on to allow this feature (Setup -&gt; General -&gt; CD/DVD Monitor</source>
        <translation>El Monitor de Medios debe estar activado para permitir esta función (Configuración -&gt; General -&gt; Monitor CD/DVD</translation>
    </message>
    <message>
        <source>Display mythdvd menu</source>
        <translation>Mostrar menú mythdvd</translation>
    </message>
    <message>
        <source>ISO copy of %1</source>
        <translation>Copia ISO de %1</translation>
    </message>
    <message>
        <source>Waiting for access to DVD</source>
        <translation>Esperando por acceso a DVD</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>Ripear/Trascodificar</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>Trabajo 1 de 1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Duración:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>Seleccione:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Calidad:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>Banda de audio:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>Audio AC3:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>Subtítulos:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>Ver:</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>Título 1 de 1</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>Desconocido</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - Título de %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfecto</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>Título %1 de %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0 Procesar el título seleccionado</translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0 Procesar los títulos seleccionados</translation>
    </message>
    <message>
        <source>ISO Image</source>
        <translation>Imágen ISO</translation>
    </message>
</context>
</TS>
